@@ -37,9 +37,7 @@ except ImportError as error:
 
 
 from numpy import array, array_equal
-from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Normalization import Normalization
 
 
 class DataFreq(DataND):
