@@ -6,15 +6,16 @@ from matplotlib.backends.backend_qt5agg import (
     FigureCanvas,
     NavigationToolbar2QT as NavigationToolbar,
 )
-from SciDataTool.Functions.Plot.init_fig import init_fig
+from SciDataTool.Functions.Plot.init_fig import init_fig, copy_fig
 from matplotlib.lines import Line2D
 from matplotlib.patches import Rectangle
 from matplotlib.collections import PathCollection, QuadMesh
 from matplotlib.text import Annotation
 from numpy import array
-from SciDataTool.Functions.Plot import ifft_dict, fft_dict
+from SciDataTool.Functions.is_axes_in_order import is_axes_in_order
 from SciDataTool.Functions.Plot import TEXT_BOX
 
+
 SYMBOL_DICT = {
     "time": "t",
     "angle": "\\alpha",
@@ -71,6 +72,9 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         is_auto_refresh=False,
         frozen_type=0,
         plot_arg_dict=dict(),
+        save_path="",
+        logger=None,
+        path_to_image=None,
     ):
         """Initialize the UI according to the input given by the user
 
@@ -96,6 +100,12 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             Dictionnary with arguments that must be given to the plot
         frozen_type : int
             0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them, 3 to freeze both axes and operations, 4 to freeze fft
+        save_path : str
+            path to the folder where the animations are saved
+        logger : logger
+            logger used to print path to animation (if None using print instead)
+        path_to_image : str
+            path to the folder where the image for the animation button is saved
         """
 
         # Build the interface according to the .ui file
@@ -134,6 +144,11 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             z_max=z_max,
             frozen_type=frozen_type,
             is_quiver=is_quiver,
+            plot_arg_dict=plot_arg_dict,
+            save_path=save_path,
+            logger=logger,
+            path_to_image=path_to_image,
+            main_widget=self,
         )
 
         # Building the interaction with the UI itself
@@ -276,7 +291,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                     ylabel = latex(SYMBOL_DICT[axes_selected_parsed[1].name.lower()])
                 else:
                     ylabel = latex(axes_selected_parsed[1].name)
-                yunit = "[" + latex(axes_selected_parsed[1].unit) + "]"
+                yunit = "[" + axes_selected_parsed[1].unit + "]"
 
             else:
                 if self.data.name.lower() in SYMBOL_DICT:
@@ -489,42 +504,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         ] = self.w_plot_manager.get_plot_info()
 
         # Checking if the axes are following the order inside the data object
-        axes_selected_parsed = parser.read_input_strings(axes_selected, axis_data=None)
-        axes_name = [ax.name for ax in self.data.get_axes()]
         not_in_order = False
 
         if len(axes_selected) == 2:
-            if (
-                axes_selected_parsed[0].name in axes_name
-                and axes_selected_parsed[1].name in axes_name
-            ):
-                if axes_name.index(axes_selected_parsed[0].name) > axes_name.index(
-                    axes_selected_parsed[1].name
-                ):
-                    not_in_order = True
-                    axes_selected = [axes_selected[1], axes_selected[0]]
-
-            elif (
-                axes_selected_parsed[0].name in ifft_dict
-                and axes_selected_parsed[1].name in ifft_dict
-            ):
-                if axes_name.index(
-                    ifft_dict[axes_selected_parsed[0].name]
-                ) > axes_name.index(ifft_dict[axes_selected_parsed[1].name]):
-
-                    not_in_order = True
-                    axes_selected = [axes_selected[1], axes_selected[0]]
-
-            elif (
-                axes_selected_parsed[0].name in fft_dict
-                and axes_selected_parsed[1].name in fft_dict
-            ):
-                if axes_name.index(
-                    fft_dict[axes_selected_parsed[0].name]
-                ) > axes_name.index(fft_dict[axes_selected_parsed[1].name]):
-
-                    not_in_order = True
-                    axes_selected = [axes_selected[1], axes_selected[0]]
+            not_in_order, axes_selected = is_axes_in_order(axes_selected, self.data)
 
         if not None in data_selection:
             if len(axes_selected) == 1:
@@ -550,6 +533,8 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                         if plot_arg_dict_2D["is_smallestperiod"]:
                             angle_str = "angle[smallestperiod]"
                         del plot_arg_dict_2D["is_smallestperiod"]
+                    if "fig" in plot_arg_dict_2D:
+                        del plot_arg_dict_2D["fig"]
                     self.data_orig.plot_2D_Data(
                         *[*[angle_str], *data_selection],
                         **plot_arg_dict_2D,
@@ -604,6 +589,8 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                     plot_arg_dict_3D["z_min"] = output_range["min"]
                 if output_range["max"] is not None:
                     plot_arg_dict_3D["z_max"] = output_range["max"]
+                if "is_switch_axes" in plot_arg_dict_3D:
+                    del plot_arg_dict_3D["is_switch_axes"]
                 self.data.plot_3D_Data(
                     *[*axes_selected, *data_selection],
                     **plot_arg_dict_3D,
@@ -626,6 +613,9 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
         plot_arg_dict=dict(),
         is_keep_config=False,
         frozen_type=0,
+        save_path="",
+        logger=None,
+        path_to_image=None,
     ):
         """Method to set the DDataPlotter with information given
         self : DDataPlotter
@@ -638,6 +628,12 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             Dictionnary with arguments that must be given to the plot
         frozen_type : int
             0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them, 3 to freeze both axes and operations, 4 to freeze fft
+        save_path : str
+            path to the folder where the animations are saved
+        logger : logger
+            logger used to print path to animation (if None using print instead)
+        path_to_image : str
+            path to the folder where the image for the animation button is saved
         """
 
         self.plot_arg_dict = plot_arg_dict
@@ -655,7 +651,11 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             axes_request_list=axes_request_list,
             is_keep_config=is_keep_config,
             frozen_type=frozen_type,
+            plot_arg_dict=plot_arg_dict,
             is_quiver=is_quiver,
+            save_path=save_path,
+            logger=logger,
+            path_to_image=path_to_image,
         )
 
     def showEvent(self, ev):
