@@ -87,7 +87,7 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
                 axis_unit_selected += "[]"
 
         if self.norm is not None:  # Add normalization
-            axis_unit_selected += "->" + self.norm
+            axis_unit_selected += "{" + self.norm + "}"
 
         elif axis_unit_selected != "None":  # adding unit
             axis_unit_selected += "{" + self.c_unit.currentText() + "}"
@@ -205,7 +205,9 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
 
         # Step 2 : Recovering the unit and setting the combobox according to it
         unit_name = axis.unit
-        if unit_name in unit_dict:
+        if self.c_unit.findText(unit_name) != -1:
+            self.c_unit.setCurrentIndex(self.c_unit.findText(unit_name))
+        elif unit_name in unit_dict:
             self.c_unit.setCurrentIndex(self.c_unit.findText(unit_dict[unit_name]))
         elif unit_name in norm_name_dict:
             self.c_unit.setCurrentIndex(self.c_unit.findText(norm_name_dict[unit_name]))
